@@ -18,7 +18,7 @@
 
 #include "history2plugin.h"
 
-#include <QtCore/QList>
+#include <QList>
 
 #include <kpluginfactory.h>
 #include <kaboutdata.h>
@@ -61,8 +61,8 @@ History2Plugin::History2Plugin(QObject *parent, const QStringList & /* args */)
     connect(Kopete::ContactList::self(), SIGNAL(metaContactSelected(bool)),
             viewMetaContactHistory, SLOT(setEnabled(bool)));
 
-    connect(Kopete::ChatSessionManager::self(), SIGNAL(viewCreated(KopeteView *)),
-            this, SLOT(slotViewCreated(KopeteView *)));
+    connect(Kopete::ChatSessionManager::self(), SIGNAL(viewCreated(KopeteView*)),
+            this, SLOT(slotViewCreated(KopeteView*)));
 
     connect(this, SIGNAL(settingsChanged()), this, SLOT(slotSettingsChanged()));
 
@@ -74,8 +74,8 @@ History2Plugin::History2Plugin(QObject *parent, const QStringList & /* args */)
     for (QList<Kopete::ChatSession *>::Iterator it = sessions.begin(); it != sessions.end(); ++it) {
         if (!m_loggers.contains(*it)) {
             m_loggers.insert(*it, new History2GUIClient(*it));
-            connect(*it, SIGNAL(closing(Kopete::ChatSession *)),
-                    this, SLOT(slotKMMClosed(Kopete::ChatSession *)));
+            connect(*it, SIGNAL(closing(Kopete::ChatSession*)),
+                    this, SLOT(slotKMMClosed(Kopete::ChatSession*)));
         }
     }
 }
@@ -102,8 +102,8 @@ void History2Plugin::messageDisplayed(const Kopete::Message &m)
 
     if (!m_loggers.contains(m.manager())) {
         m_loggers.insert(m.manager(), new History2GUIClient(m.manager()));
-        connect(m.manager(), SIGNAL(closing(Kopete::ChatSession *)),
-                this, SLOT(slotKMMClosed(Kopete::ChatSession *)));
+        connect(m.manager(), SIGNAL(closing(Kopete::ChatSession*)),
+                this, SLOT(slotKMMClosed(Kopete::ChatSession*)));
     }
 
     QList<Kopete::Contact *> mb = m.manager()->members();
@@ -143,8 +143,8 @@ void History2Plugin::slotViewCreated(KopeteView *v)
 
     if (!m_loggers.contains(m_currentChatSession)) {
         m_loggers.insert(m_currentChatSession, new History2GUIClient(m_currentChatSession));
-        connect(m_currentChatSession, SIGNAL(closing(Kopete::ChatSession *)),
-                this, SLOT(slotKMMClosed(Kopete::ChatSession *)));
+        connect(m_currentChatSession, SIGNAL(closing(Kopete::ChatSession*)),
+                this, SLOT(slotKMMClosed(Kopete::ChatSession*)));
     }
 
     if (!autoChatWindow || nbAutoChatWindow == 0) {
